"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Pattern_1 = require("./Pattern");
/**
 * Checks if an object is a valid path
 * @param p the object to check
 * @returns true if {@code p} is a valid path
 */
function isPath(p) {
    return (Pattern_1.isPattern(p) &&
        new Array().concat(p).every(function (s) {
            return ((typeof s === "string" || typeof s === "number") &&
                s !== "*" &&
                s !== "**");
        }));
}
exports.isPath = isPath;
/**
 * Checks if an path contains number-like strings
 * @param p the path to check
 * @returns true, if {@code p} contains a number-like string
 */
function hasNumberlikeStrings(p) {
    return new Array().some(function (s) {
        return typeof s === "string" && !isNaN(Number(s));
    });
}
exports.hasNumberlikeStrings = hasNumberlikeStrings;
//# sourceMappingURL=Path.js.map