import { Pattern } from "./Pattern";
import { Path } from "./Path";
/**
 * Expands a pattern to all matching conrete paths over an object
 * @param pattern the pattern to expand
 * @param object the object to expand onto
 *
 * @example
 * ```javascript
 * const o = {
 *   foo: {
 *     bar: "bar",
 *     baz: "baz",
 *   },
 *   foo2: [
 *     "one",
 *     "two",
 *   ]
 * }
 * let result = expand(["*"], o)
 * // result === [ ["foo"], ["foo2"] ]
 * let result = expand(["*", "*"], o)
 * // result === [ ["foo", "bar"], ["foo", "baz"], ["foo2", 0], ["foo2", 1] ]
 * let result = expand(["foo", "*"], o)
 * // result ===  [ ["foo", "bar"], ["foo", "baz"] ]
 * ```
 */
declare function expand(pattern: Pattern, object: object | any[]): Path[];
export default expand;
export { expand };
