"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Path_1 = require("./Path");
/**
 * Retrieves a value in an object described by an path
 * @param path the path at which the objects value should be retrieved
 * @param obj the object to retrieve a value from
 *
 * @example
 * ```javascript
 * const object = { foo: [null, { bar: "BAR" }] }
 * const result = get(["foo", 1, "bar"], object)
 * // result === "BAR"
 * ```
 */
function get(path, obj) {
    if (process && process.env && process.env.NODE_ENV === "development") {
        if (!Path_1.isPath(path)) {
            throw new TypeError(path + " is not a valid path");
        }
    }
    var pathArr = new Array().concat(path);
    return pathArr.reduce(function (o, segment) {
        if (null !== o && undefined !== o) {
            return o[segment];
        }
        else {
            return o;
        }
    }, obj);
}
exports.get = get;
exports.default = get;
//# sourceMappingURL=get.js.map