"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var Path_1 = require("./Path");
/**
 * Creates an object that is similiar to a given object but differs at a specific path
 *
 * @param path the path at which the the created object shall be different
 * @param obj the object to use as blueprint
 * @param value the value to insert at the given path
 *
 * @example
 * ```javascript
 * const object = { foo: [null, { bar: "BAR" }] }
 *
 * let result = set(["foo", 0, "baz"], object, "baz")
 * // result === { foo: ["baz", { bar: "BAR" }] }
 * // object === { foo: [null, { bar: "BAR" }] } !
 *
 * // with autovivication
 * const object = {}
 *
 * let result = set(["foo", 0, "baz"], object, "baz")
 * // result === { foo: ["baz", { bar: "BAR" }] }
 * // *missing* segments will be created on the fly
 * // if `typeof segment === "string"`  an empty object will be created at the non-existing path
 * // if `typeof segment === "number"`  an empty array will be created at the non-existing path
 * ```
 */
function set(path, obj, value) {
    if (process && process.env && process.env.NODE_ENV === "development") {
        if (!Path_1.isPath(path)) {
            throw new TypeError(path + " is not a valid path");
        }
    }
    var pathArr = new Array().concat(path);
    if (pathArr.length === 0) {
        return value;
    }
    else {
        var segment = pathArr[0];
        var numberSegment = isNaN(+segment) ? NaN : +segment;
        var isNumber = !isNaN(numberSegment);
        var objOrDefault = obj || (isNumber ? new Array(segment) : {});
        if (isNumber) {
            return objOrDefault.slice(0, segment).concat([
                set(pathArr.slice(1), objOrDefault[segment], value)
            ], objOrDefault.slice(segment + 1));
        }
        else {
            return __assign({}, objOrDefault, (_a = {}, _a[segment] = set(pathArr.slice(1), objOrDefault[segment], value), _a));
        }
    }
    var _a;
}
exports.set = set;
exports.default = set;
//# sourceMappingURL=set.js.map