import { Path } from "./Path";
/**
 * Retrieves all primitive value and their corresponding paths from an object
 *
 * The order of the returned values is not guarenteed to be sorted in any way
 *
 * @param object the object to retrieve all primitives values from
 * @return an array of all primitive values and their corresponding paths
 *
 * @example
 * ```javascript
 * const object = { foo: { bar: "bar", baz: [true, 0] }}
 * const result = values(object)
 * // result === [
 *   { path: [ "foo", "bar", ], value: "bar" },
 *   { path: [ "foo", "baz", 0 ], value: true },
 *   { path: [ "foo", "baz", 1 ], value: 0 }
 * ]
 * ```
 */
declare function valuesAndPaths(object: object | any[]): Array<{
    path: Path;
    value: any;
}>;
export default valuesAndPaths;
export { valuesAndPaths };
